#! /usr/bin/env bash

source util.sh

VERSION=$1
PREFIX="$2"
URL="https://ftp.gnu.org/gnu/gdb/gdb-$VERSION.tar.xz"
ARCHIVE=$(basename "$URL")

# Final location of gdb in the sysroot
SYSROOT_GDB="$SYSROOT/bin/sh-elf-gdb"
# Version string of any existing sh-elf-gdb in the sysroot
SYSROOT_GDB_VERSION=

#---
# Determine what versions are already here and decide whether to skip
#---

if command -v sh-elf-gdb; then
  SYSROOT_GDB_VERSION=$(sh-elf-gdb --version | head -n 1 | grep -Eo '[0-9.]+$')
fi

if [[ "$SYSROOT_GDB_VERSION" = "$VERSION" ]]; then
  echo "$TAG gdb $VERSION already installed, skipping rebuild"
  [[ -d build ]] && touch "build/giteapc-skip-rebuild.txt"
  exit 0
fi

if [[ ! -z "$ACCEPT_ANY" && ! -z "$SYSROOT_GDB_VERSION" ]]; then
  echo "$TAG gdb $SYSROOT_GDB_VERSION is available; skipping as per ACCEPT_ANY"
  [[ -d build ]] && touch "build/giteapc-skip-rebuild.txt"
  exit 0
fi

#---
# Get sources
#---

if [[ -f "$ARCHIVE" ]]; then
  echo "$TAG Found $ARCHIVE, skipping download"
else
  echo "$TAG Downloading $URL..."
  if command -v curl >/dev/null 2>&1; then
    curl "$URL" -o "$ARCHIVE"
  elif command -v wget >/dev/null 2>&1; then
    wget -q --show-progress "$URL" -O "$ARCHIVE"
  else
    echo "$TAG error: no curl or wget; install one or download archive yourself" >&2
    exit 1
  fi
fi

# Extract archive (OpenBSD-compliant version)
echo "$TAG Extracting $ARCHIVE..."
unxz -c < "$ARCHIVE" | tar -xf -

if [[ "$VERSION" = "14.2" ]]; then
  echo "$TAG Applying patches/gdb-14.2-sh4al-dsp-register-types.patch..."
  patch -u -N -p0 < patches/gdb-14.2-sh4al-dsp-register-types.patch
fi

#---
# Configure
#---

# We install in the sysroot and then symlink to the PREFIX folder in the path
[[ -d "build" ]] && rm -rf build
mkdir build && cd build

echo "$TAG Configuring gdb..."

run_quietly giteapc-configure.log       \
../gdb-$VERSION/configure               \
  --prefix="$SYSROOT"                   \
  --target="sh3eb-elf"                  \
  --with-multilib-list="m3,m4-nofpu"    \
  --program-prefix="sh-elf-"            \
  --enable-libssp                       \
  --enable-lto
